/*! For license information please see 4848.49f1c73a468b6d6146f1.js.LICENSE.txt */
"use strict";(self.webpackChunkeodag_labextension=self.webpackChunkeodag_labextension||[]).push([[4848],{1020:(e,r,o)=>{var t=o(3345),n=Symbol.for("react.element"),s=(Symbol.for("react.fragment"),Object.prototype.hasOwnProperty),_=t.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED.ReactCurrentOwner,a={key:!0,ref:!0,__self:!0,__source:!0};function f(e,r,o){var t,f={},l=null,p=null;for(t in void 0!==o&&(l=""+o),void 0!==r.key&&(l=""+r.key),void 0!==r.ref&&(p=r.ref),r)s.call(r,t)&&!a.hasOwnProperty(t)&&(f[t]=r[t]);if(e&&e.defaultProps)for(t in r=e.defaultProps)void 0===f[t]&&(f[t]=r[t]);return{$$typeof:n,type:e,key:l,ref:p,props:f,_owner:_.current}}r.jsx=f,r.jsxs=f},4848:(e,r,o)=>{e.exports=o(1020)}}]);