.jp-EodagWidget-form-buttons-wrapper {
  display: flex;
  gap: 0.5rem;
  padding: 0 10px;
  justify-content: flex-end;
}

.jp-EodagButton {
  gap: 0.5rem;
  border-radius: 6px !important;
  text-transform: none !important;
  line-height: 1.4 !important;
  font-size: 14px !important;
}

.jp-EodagButton svg {
  width: 1.15rem;
  height: 1.15rem;
}
