.loadingState {
  position: relative;
}

.loadingState .loadingStateFilter {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: rgba(0, 0, 0, 0.25);
  z-index: 100;
}

.loading-state {
  position: relative;
}

.loader-container {
  position: absolute;
  display: flex;
  align-items: center;
  justify-content: center;
  opacity: 1;
  z-index: 2;
  border-radius: 4px;
  transition: opacity 250ms ease-in-out;
  pointer-events: all;
  background: rgba(255, 255, 255, 0.65);
  width: 100%;
  height: 100%;
}

.jp-EodagWidget-select__menu {
  /* To go over the loader */
  z-index: 3 !important;
}

.loader-container.fade-out {
  opacity: 0;
}

.loader-container .loader-icon {
  transform: scale(30%);
}

.loader-icon * {
  margin: 2px 6px !important;
  background: rgb(0, 120, 212) !important;
}
