/* Exit Button */

.jp-EodagWidget-modal-exit-button {
  position: absolute !important;
  z-index: 1;
  top: 16px;
  right: 16px;
  height: 28px;
  width: 28px;
  background-color: white !important;
  border-radius: 32px !important;
}

/* Background map */

.jp-EodagWidget-background-map {
  position: absolute;
  inset: 0;
}

/* Left panel */

.jp-EodagWidget-modal-results {
  position: absolute;
  inset: 24px auto 24px 24px;
  width: 450px;
  height: calc(100% - 96px); /* 48 + 48 = 96 */
  background: white;
  border-radius: 12px;
  box-shadow: 3px 0 10px rgb(0 0 0 / 25%);
  padding: 1.5rem 0; /* No padding left & right, to prevent the shadows from being overflowed */
}

.jp-EodagWidget-modal-results .jp-EodagWidget-results-wrapper {
  display: flex;
  flex-direction: column;
  gap: 1.5rem;
  width: 100%;
  height: 100%;
}

/* Left panel > Title container */

.jp-EodagWidget-modal-results
  .jp-EodagWidget-results-wrapper
  .jp-EodagWidget-results-title {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  padding: 0 1.5rem;
}

.jp-EodagWidget-modal-results
  .jp-EodagWidget-results-wrapper
  .jp-EodagWidget-results-title
  h2 {
  margin: 0;
  font-size: 1.25rem;
  line-height: 1.5rem;
  font-weight: 600;
}

.jp-EodagWidget-modal-results
  .jp-EodagWidget-results-wrapper
  .jp-EodagWidget-results-title
  .jp-EodagWidget-results-subtitle {
  display: flex;
  flex-direction: row;
  gap: 0.5rem;
}

.jp-EodagWidget-modal-results
  .jp-EodagWidget-results-wrapper
  .jp-EodagWidget-results-title
  .jp-EodagWidget-results-subtitle
  span {
  font-size: 0.75rem;
  font-weight: 400;
  color: #808080;
}

/* Left panel > content */

.jp-EodagWidget-modal-results
  .jp-EodagWidget-results-wrapper
  .jp-EodagWidget-results-content {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  flex: 1;
}

/* Left panel > footer (buttons) */

.jp-EodagWidget-modal-results
  .jp-EodagWidget-results-wrapper
  .jp-EodagWidget-results-footer {
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
  padding: 0 1.5rem;
}

.jp-EodagWidget-modal-results
  .jp-EodagWidget-results-wrapper
  .jp-EodagWidget-results-footer
  .jp-EodagWidget-apply {
  border-radius: 6px;
  text-transform: unset !important;
}

/* Only !important because we don't use mui styling process */

.jp-EodagWidget-chip {
  padding: 0 1px !important;
  background-color: white !important;
  color: #7bb4ff !important;
  border: 1px solid #7bb4ff !important;
  height: 20px !important;
}

.jp-EodagWidget-chip svg {
  font-size: 14px !important;
  color: #7bb4ff !important;
}

.jp-EodagWidget-chip span {
  padding: 0 4px 0 8px !important;
  font-size: 11px !important;
  font-weight: 600;
}

/* Selected Feature component */

.jp-EodagWidget-modal-selected-result {
  position: absolute;
  inset: auto 24px 24px 498px; /* 450px + 24 gap x2 */
  height: 250px;
  background: white;
  border-radius: 12px;
  box-shadow: 3px 0 10px rgb(0 0 0 / 25%);
  padding: 1.5rem;
  display: flex;
  flex-direction: row;
  gap: 1.5rem;
  transition: 0.25s height ease-in-out;
}

.jp-EodagWidget-modal-selected-result-panel-tools {
  display: flex;
  position: absolute;
  inset: 4px 4px auto auto;
}

.jp-EodagWidget-modal-selected-result-panel-tools button {
  border-radius: 32px;
  padding: 2px;
}

.jp-EodagWidget-modal-selected-result.panelZoomed {
  height: calc(100% - 96px);
}

.jp-EodagWidget-modal-selected-result-preview {
  width: 250px;
  min-width: 250px;
  height: 250px;
  border-radius: 8px;
  overflow: hidden;
  border: 1px solid rgba(0 0 0 / 10%);
  position: relative;
}

.jp-EodagWidget-modal-selected-result-preview img {
  min-width: 100%;
  width: 100%;
  min-height: 100%;
  height: 100%;
  position: relative;
}

.jp-EodagWidget-modal-selected-result-infos {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  flex: 1;
  width: calc(100% - 274px);
}

.jp-EodagWidget-modal-selected-result-title {
  display: flex;
  justify-content: space-between;
  align-items: flex-start;
  gap: 1.5rem;
  width: 95%;
}

.jp-EodagWidget-modal-selected-result-title span {
  font-size: 1.2rem;
  line-height: 1.7rem;
  font-weight: 600;
  word-break: break-all;
}

.jp-EodagWidget-modal-selected-result-zoomButton {
  background-color: #007aff !important;
  color: white !important;
  border-radius: 5px !important;
}

.jp-EodagWidget-modal-selected-result-metadata {
  display: flex;
  flex-direction: column;
  flex: 1;
  border: 1px solid rgba(68 68 68 / 10%);
  border-radius: 8px;
  overflow: scroll;
}

.jp-EodagWidget-modal-selected-result-metadata-title {
  display: flex;
  gap: 1.5rem;
  padding: 0.5rem 0.75rem;
  background-color: #e4e4e4;
  color: black;
}

.jp-EodagWidget-modal-selected-result-metadata-title span {
  flex: 1;
  font-size: 1rem;
  line-height: 1.25rem;
}

.jp-EodagWidget-modal-selected-result-metadata-content {
  padding: 0.75rem 1.15rem;
  display: flex;
  gap: 0.75rem 0;
  flex-wrap: wrap;
  justify-content: space-between;
  overflow: scroll;
  overflow-x: hidden;
}

.jp-EodagWidget-modal-selected-result-metadata-line {
  display: flex;
  flex-direction: row;
  gap: 1rem;
  width: 49%;
}

.jp-EodagWidget-modal-selected-result-metadata-line span {
  font-weight: 400;
  color: #444444;
  font-size: 1rem;
  line-height: 1.32rem;
  max-width: 45%;
  overflow: hidden;
  text-wrap: nowrap;
  text-overflow: ellipsis;
}

.jp-EodagWidget-modal-selected-result-metadata-line .separator {
  flex: 1;
  border-bottom: 1px solid rgba(68 68 68 / 10%);
}

.jp-EodagWidget-modal-selected-result-action-buttons {
  display: flex;
  justify-content: flex-end;
}

.jp-EodagWidget-modal-selected-result-action-buttons button {
  text-transform: unset;
  border-radius: 6px;
}
